@@ -146,7 +146,11 @@ ephy_web_overview_model_urls_changed (EphyWebOverviewModel *model,
 
       class_list = webkit_dom_element_get_class_list (webkit_dom_node_get_parent_element (WEBKIT_DOM_NODE (item->anchor)));
       if (class_list && webkit_dom_dom_token_list_contains (class_list, "overview-removed"))
+#if WEBKIT_CHECK_VERSION(2, 13, 2)
+        webkit_dom_dom_token_list_remove (class_list, NULL, "overview-removed", NULL);
+#else
         webkit_dom_dom_token_list_remove (class_list, "overview-removed", NULL);
+#endif
 
       webkit_dom_element_set_attribute (item->anchor, "href", url->url, NULL);
       webkit_dom_element_set_attribute (item->anchor, "title", url->title, NULL);
